; === IRecho5_08M.bas ========== 2009.01.12 ========== Ron Hackett ===

;	This TankBot program runs on a PICAXE-08M slave processor at 8 MHz.
;	It emits 42 kHz IR PWM bursts & checks for echoes after each burst.

; ====================================================================


; === Constants ===

	symbol	 LED_L = 0			;  Left visible LED on output 0 (pin 7)
	symbol	 LED_R = 1			; Right visible LED on output 1 (pin 6)
	symbol	 IRout = 2			;  Both IR LEDs on PWM output 2 (pin 5)
	symbol	  reps = 5			; used to test for valid echoes
		
; The output of the right IR detector is connected to input 3 (pin 4)
; The output of the  left IR detector is connected to input 4 (pin 3)

	 	 	 
; === Variables ===

	symbol	echoes = b0				; used to store echo values
	symbol	echo_L = bit4			; used to access  left echo value
	symbol	echo_R = bit3			; used to access right echo value
	symbol	 eLeft = b1
	symbol	eRight = b2
	symbol	 index = b3


; === Directives ===

	#com2									; specify serial port
	#picaxe 08M							; specify PICAXE processor	


; === Beginning of Main Program ======================================

	setfreq m8						 	; set internal resonator to 8 MHz
	let dirs = %00000111			 	; set pins 0,1 & 2 as outputs
										 	; set pins 3 and 4 as inputs
										 	
	 do									; The following is an infinite loop
	   eLeft  = 0						; initialize the left  echo counter
	   eRight = 0						; initialize the right echo counter
	   	      
	   for index = 1 to reps		; check for echo after each PWM burst
	     pwmout IRout,47,95			; PWM burst detuned to 42 kHz, 50% DS
	     pause 20						; transmit IR PWM for 20 mS
	     pwmout IRout off			; PWM off
	     echoes = pins				; capture echoes
	     
	     if echo_L = 0 then			; if echo then increment eCount
	        inc eLeft   
	     endif
	     
	     if echo_R = 0 then			; if echo then increment eCount
	        inc eRight   
	     endif
	     
	     pause 20
	   next index
	 
	   if eLeft = reps then			; five in a row is valid echo
	     	high LED_L					; so value of 0 indicates obstacle
	  	else
	     	low LED_L
	  	endif

	  	if eRight = reps then		; PNA4602 is active-low,
	     	high LED_R					; so value of 0 indicates obstacle
	  	else
	     	low LED_R
	  	endif

	 loop									; loop forever


