
; === TankBotIR.bas ============ 2009.01.12 ============ Ron Hackett ===

;	This is a simple IR obstacle detection program for the SERVO Tankbot.
;	It receives IR echo detection data from a slave PICAXE-08M processor.
;	As long as there is no obstacle ahead, Tankot moves straight forward.
;	If an obstacle is indicated, TankBot turns until its path is clear,
;  then resumes moving forward.

; ======================================================================


; === Constants ===

	symbol IR_L = pin3					;  left IR detector input on input 3
	symbol IR_R = pin4					; right IR detector input on input 4	
	symbol motR =    4					; right servo Motor on output 4
	symbol motL =    5					;  left servo Motor on output 5
	 	
	symbol  fdL =  183					; for my  left servo, 133+50=183
	symbol  bkL =   83					; for my  left servo, 133-50= 83
	symbol  fdR =   83					; for my right servo, 133-50= 83
	symbol  bkR =  183					; for my right servo, 133+50=183


; === Directives ===

	#com1										; specify serial port
	#picaxe 14M								; specify PICAXE processor
	

; === Begin Main Program ===============================================

	wait 2
	
	do		
	  servo motL, fdL						; go straight forward
	  servo motR, fdR
	
	  do										; keep going straight ahead
	  loop until IR_L=1 or IR_R=1		; until obstacle is detected
												
	  gosub Stopp							; stop before changing direction
												; to reduce strain on servos 
												
	  if IR_L = 1 then					; if obstacle on left,
		  servo motL, fdL					; then turn right
	     servo motR, bkR
	     gosub Spin						; & continue turning until all clear
	  elseif IR_R = 1 then				; else if obstacle on right,
	     servo motL, bkL					; then turn left
	     servo motR, fdR
	     gosub Spin						; & continue turning until all clear
	  endif
	  
	  gosub Stopp							; stop before changing direction
												; to reduce strain on servos  		
	loop
	

; === End Main Program - Subroutines Follow ============================


; === Spin Subroutine ==================================================

Spin:
	do
	loop until IR_L=0 and IR_R=0		; keep turning until all clear
	pause 250								; and a little more for good measure
	return


; === Stopp Subroutine =================================================

Stopp:										; "Stop" is reserved word: can't use
	low MotL
	low MotR	
	pause 250
	
	return		



